// @ts-check
// `@type` JSDoc annotations allow editor autocompletion and type checking
// (when paired with `@ts-check`).
// There are various equivalent ways to declare your Docusaurus config.
// See: https://docusaurus.io/docs/api/docusaurus-config

import {themes as prismThemes} from 'prism-react-renderer';

/** @type {import('@docusaurus/types').Config} */
const config = {

  
  title: 'FAB24 - ChaiHuo Makerspace 2024',
  tagline: '',
  favicon: 'img/favicon.ico',

  // Set the production url of your site here
  url: 'https://your-docusaurus-site.example.com',
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: '/2024/labs/chaihuo/',

  // GitHub pages deployment config.
  // If you aren't using GitHub pages, you don't need these.
  organizationName: 'facebook', // Usually your GitHub org/user name.
  projectName: 'docusaurus', // Usually your repo name.

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  // Even if you don't use internationalization, you can use this field to set
  // useful metadata like html lang. For example, if your site is Chinese, you
  // may want to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: 'en',
    locales: ['en'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: {
          sidebarPath: './sidebars.js',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          editUrl:
            'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          editUrl:
            'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: './src/css/custom.css',
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      // Replace with your project's social card
      image: 'img/docusaurus-social-card.jpg',
      tableOfContents: {
        minHeadingLevel: 2,
        maxHeadingLevel: 5,
      },
      navbar: {
        title: 'Chaihuo Makerspace 2024:',
        logo: {
          alt: 'Logo',
          src: 'img/favicon.png',
        },
        items: [
          {
            type: 'dropdown',
            label: ' Assignments ',
            // to: '/Getting_Started',
            position: 'left',
            className: 'navbar_doc_items',
            items: [
              {
                "label": "Week 3 - Computer-Controlled Cutting ✅",
                "to": "docs/assignment/week-03computer-controlled-cutting"
              },
              {
                "label": "Week 4 - Electronics Production ✅",
                "to": "docs/assignment/week-04-electronics-production"
              },
              {
                "label": "Week 5 - 3D Scanning And Printing ✅",
                "to": "docs/assignment/week-053d-scanning-and-printing/"
              },
              {
                "label": "Week 6 - Embedded Programming ✅",
                "to": "docs/assignment/week-06embedded-programming/"
              },
              {
                "label": "Week 7 - Computer-Controlled Machining ✅",
                "to": "docs/assignment/week-07computer-controlled-machining/"
              },
              {
                "label": "Week 8 - Electronics Design ✅",
                "to": "docs/assignment/week-08-electronics-design/"
              },
              {
                "label": "Week 9 - Output Devices ✅",
                "to": "docs/assignment/week-09output-devices/"
              },
              {
                "label": "Week 10 - Mechanical Design, Machine Design ✅",
                "to": "docs/assignment/week-10mechanical-design-machine-design./"
              },
              {
                "label": "Week 12 - Input Devices ✅",
                "to": "docs/assignment/week-12input-device/"
              },
              {
                "label": "Week 13 - Molding And Casting ✅",
                "to": "docs/assignment/week-13molding-and-casting/"
              },
              {
                "label": "Week 14 - Networking And Communications ✅",
                "to": "docs/assignment/week-14networking-and-communications/"
              },
              {
                "label": "Week 15 - Interface And Application Programming ✅",
                "to": "docs/assignment/week15interface-and-application-programming/"
              },
             
            ]
          },
          {
            type: 'doc',
            docId: 'students/teacher',
            // to: 'docs/week1_assignment',
            label: 'Fab Academy 2024 Teacher',
            position: 'left',
            className: 'navbar_doc_items',
          },
          {
            type: 'dropdown',
            label: 'Fab Academy 2024 Students',
            to: '/docs/students',
            position: 'left',
            className: 'navbar_doc_items',
            items: [
              {
                label: 'Matthew Yu',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/matthew-yu/',
              },
              {
                label: 'ChenXin Yang',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/chenxin-yang/',
              },
              {
                label: 'Jiawei Liang',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/jiawei-liang/about/',
              },
              {
                label: 'Dion Tsang',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/dion-tsang/about/',
              },
              {
                label: 'Crail Lyu',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/crail-lyu/About/',
              },
              {
                label: 'Katherine Ma',
                to: 'https://fabacademy.org/2024/labs/chaihuo/students/runyu-ma/about.html',
              },
            ],
          },
          {
            to: 'https://gitlab.fabcloud.org/academany/fabacademy/2024/labs/chaihuo/site',
            label: 'GitLab',
            position: 'right',
          },
          // {to: '/blog', label: 'Blog', position: 'left'},
          // {
          //   href: 'https://github.com/facebook/docusaurus',
          //   label: 'GitHub',
          //   position: 'right',
          // },
        ],
      },
      footer: {
        style: 'dark',
        links: [
          // {
          //   title: 'Docs',
          //   items: [
          //     {
          //       label: 'Tutorial',
          //       to: '/docs/intro',
          //     },
          //   ],
          // },
          // {
          //   title: 'Community',
          //   items: [
          //     {
          //       label: 'Stack Overflow',
          //       href: 'https://stackoverflow.com/questions/tagged/docusaurus',
          //     },
          //     {
          //       label: 'Discord',
          //       href: 'https://discordapp.com/invite/docusaurus',
          //     },
          //     {
          //       label: 'Twitter',
          //       href: 'https://twitter.com/docusaurus',
          //     },
          //   ],
          // },
          // {
          //   title: 'More',
          //   items: [
          //     {
          //       label: 'Blog',
          //       to: '/blog',
          //     },
          //     {
          //       label: 'GitHub',
          //       href: 'https://github.com/facebook/docusaurus',
          //     },
          //   ],
          // },
        ],
        copyright: `Copyright © ${new Date().getFullYear()} ChaiHuo Makerspace Inc. Built with Docusaurus.`,
      },
      prism: {
        theme: prismThemes.github,
        darkTheme: prismThemes.dracula,
      },
    }),
};

export default config;
