// src/pages/index.js
import React from 'react';
import clsx from 'clsx';
import useDocusaurusContext from '@docusaurus/useDocusaurusContext';
import Layout from '@theme/Layout';
import HomepageFeatures from '@site/src/components/HomepageFeatures';
import styles from './index.module.css';

function HeroFrame({ hero }) {
  return (
    <a href={hero.link} className={styles.heroCard} style={{ textDecoration: 'none' }}>
      <img src={hero.imageUrl} alt={hero.name} className={styles.heroImage} />
      <div className={styles.heroText}>
        <h3>{hero.name}</h3>
        <p>{hero.role}</p>
      </div>
    </a>
  );
}

const heroes = [

  {
    name: 'ChenXin yang',
    role: 'In short - CPO, CTO, COO',
    imageUrl: 'https://fabacademy.org/2024/labs/chaihuo/students/chenxin-yang/images/photo.jpeg',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/chenxin-yang/'
  },
  {
    name: 'Crail Lyu',
    role: 'Sales Manager in Seeed Studio',
    imageUrl: 'https://fabacademy.org/2024/labs/chaihuo/students/crail-lyu/images/Crail_Lyu.jpg',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/crail-lyu/'
  },
  {
    name: 'Dion Tsang',
    role: 'Curriculum Develop Specialist',
    imageUrl: 'https://fabacademy.org/2024/labs/chaihuo/students/dion-tsang/images/About/image.jpg',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/dion-tsang/'
  },
  {
    name: 'Katherine Ma',
    role: 'Computer Science Teacher',
    imageUrl: 'https://fabacademy.org/2024/labs/chaihuo/students/runyu-ma/images/Me.jpg',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/runyu-ma/'
  },
  {
    name: 'Matthew Yu',
    role: 'Application Engineer in Seeed Studio',
    imageUrl: 'https://gitlab.fabcloud.org/academany/fabacademy/2024/labs/chaihuo/students/matthew-yu/-/raw/main/static/img/Matthew_Yu.jpg?ref_type=heads',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/matthew-yu/'
  },
  {
    name: 'Jiawei Liang',
    role: 'Graphic Design Leader in Seeed Studio',
    imageUrl: 'https://fabacademy.org/2024/labs/chaihuo/students/jiawei-liang/images/avatar-photo.jpg',
    link: 'https://fabacademy.org/2024/labs/chaihuo/students/jiawei-liang/'
  },


];

function HomepageHeader() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <header className={clsx('hero hero--primary', styles.heroBanner)}>
      <div className="container">
        <h1 className="hero__title">{siteConfig.title}</h1>
        <p className="hero__subtitle">{siteConfig.tagline}</p>
        <div className={styles.heroProfiles}>
          {heroes.map((hero, idx) => (
            <HeroFrame key={idx} hero={hero} />
          ))}
        </div>
      </div>
    </header>
  );
}

export default function Home() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <Layout
      title={`Hello from ${siteConfig.title}`}
      description="Description will go into a meta tag in <head />">
      <HomepageHeader />
      <main>
        <HomepageFeatures />
      </main>
    </Layout>
  );
}